@@ -667,7 +667,7 @@ videos.add_command(get_featured_video_collection_items)
     help="Amount of detail to render in the response",
     type=str,
 )
-def get_similar_videos(**kwargs):
+def find_similar_videos(**kwargs):
     """
     List similar videos
     """
@@ -675,7 +675,7 @@ def get_similar_videos(**kwargs):
     get(url="/v2/videos/" + kwargs["id"] + "/similar", params=kwargs, json_data=None)
 
 
-videos.add_command(get_similar_videos)
+videos.add_command(find_similar_videos)
 
 
 @click.command()
